@@ -133,6 +133,10 @@ sub check_href {
 		$options -> {href} .= '&_salt=' . rand;
 	}	
 	
+	if ($_REQUEST{period} and $options -> {href} !~ /^(\#|java)/ and $options -> {href} !~ /\&period=/) {
+		$options -> {href} .= "\&period=$_REQUEST{period}";
+	}	
+
 }
 
 ################################################################################
@@ -1136,6 +1140,28 @@ sub draw_form_field_image {
 
 ################################################################################
 
+=head1 draw_form_field_string
+
+ WYSIWYG-  HTML.   - C<draw_form>.    MSIE 5+.
+
+=head2 
+
+=over
+
+=item name
+
+ CGI-      C<$data>.
+
+=item label
+
+ 
+
+=back
+
+=cut
+
+################################################################################
+
 sub draw_form_field_htmleditor {
 	drawer_call ('draw_form_field_htmleditor', @_);
 }
